# TODO check that no license information gets lost
{ fetchurl, bash, stdenv, python, go, cmake, vim, vimUtils, perl, ruby, unzip
, which, fetchgit, fetchFromGitHub, fetchhg, fetchzip, llvmPackages, zip
, vim_configurable, vimPlugins, xkb_switch, git, rustracerd, fzf
, Cocoa ? null
}:

let

inherit (vimUtils.override {inherit vim;}) rtpPath addRtp buildVimPlugin
  buildVimPluginFrom2Nix vimHelpTags;
in

# TL;DR
# Add your plugin to ./vim-plugin-names
# Generate via `vim-plugin-names-to-nix`
# If plugin is complicated then make changes to ./vim2nix/additional-nix-code

# This attrs contains two sections:
# The first contains plugins added manually, the second contains plugins
# generated by call nix#ExportPluginsForNix.
# Documentation & usage see vim-utils.nix.
# attribute names should be the same as used by vim-pi to make dependency
# resolution work
rec {
  # This is not a plugin, it provides bin/vim-open-buffer-with-plugins-derivations
  # which recreates this the following derivations based on ./vim-plugin-names
  pluginnames2nix = vimUtils.pluginnames2Nix {
    name = "vim-plugin-names-to-nix";
    namefiles = [./vim-plugin-names];
  };

  # Section I
  vim-addon-vim2nix = vim2nix;

  vim2nix = buildVimPluginFrom2Nix { # use it to update plugins
    name = "vim2nix";
    src = ./vim2nix;
    dependencies = ["vim-addon-manager"];
  };


  # Section II
  # Update with vimUtils.vimPlugins.pluginnames2Nix command

  # aliasess
  "sourcemap.vim"     = sourcemap;
  Colour_Sampler_Pack = Colour-Sampler-Pack;
  YouCompleteMe       = youcompleteme;
  airline             = vim-airline;
  alternative         = a-vim; # backwards compat, added 2014-10-21
  calendar            = calendar-vim;
  coffee-script       = vim-coffee-script;
  coffeeScript        = coffee-script; # backwards compat, added 2014-10-18
  colors-solarized    = Solarized;
  colorsamplerpack    = Colour_Sampler_Pack;
  command_T           = command-t; # backwards compat, added 2014-10-18
  css_color_5056      = vim-css-color;
  ctrlp               = ctrlp-vim;
  easy-align          = vim-easy-align;
  easymotion          = vim-easymotion;
  eighties            = vim-eighties;
  ghc-mod-vim         = ghcmod;
  gist-vim            = Gist;
  gitgutter           = vim-gitgutter;
  gundo               = gundo-vim;
  Gundo               = gundo-vim; # backwards compat, added 2015-10-03
  haskellConceal      = haskellconceal; # backwards compat, added 2014-10-18
  haskellconceal      = vim-haskellconceal;
  haskellConcealPlus  = vim-haskellConcealPlus;
  hier                = vim-hier;
  hlint-refactor      = hlint-refactor-vim;
  hoogle              = Hoogle;
  ipython             = vim-ipython;
  latex-live-preview  = vim-latex-live-preview;
  multiple-cursors    = vim-multiple-cursors;
  necoGhc             = neco-ghc; # backwards compat, added 2014-10-18
  neocomplete         = neocomplete-vim;
  neosnippet          = neosnippet-vim;
  nerdcommenter       = The_NERD_Commenter;
  nerdtree            = The_NERD_tree;
  quickrun            = vim-quickrun;
  signature           = vim-signature;
  stylish-haskell     = vim-stylish-haskell;
  stylishHaskell      = stylish-haskell; # backwards compat, added 2014-10-18
  supertab            = Supertab;
  syntastic           = Syntastic;
  tabular             = Tabular;
  tagbar              = Tagbar;
  thumbnail           = thumbnail-vim;
  tmux-navigator      = vim-tmux-navigator;
  tmuxNavigator       = tmux-navigator; # backwards compat, added 2014-10-18
  tslime              = tslime-vim;
  vimproc             = vimproc-vim;
  vimshell            = vimshell-vim;
  watchdogs           = vim-watchdogs;
  webapi-vim          = WebAPI;
  wombat256           = wombat256-vim; # backwards compat, added 2015-7-8
  yankring            = YankRing;

  fzfWrapper = buildVimPluginFrom2Nix {
    name = fzf.name;
    src = "${fzf}/share/go/src/github.com/junegunn/fzf";
    dependencies = [];
  };

  # --- generated packages bellow this line ---

  CSApprox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CSApprox-2013-07-26";
    src = fetchgit {
      url = "git://github.com/godlygeek/csapprox";
      rev = "7981dac51d8b6776985aa08cb7b5ee98ea7f2ddd";
      sha256 = "08g4x6nnd6hkgm2daa5ihhz75pcdx3jzzv8rfjls80qajlhx5rf6";
    };
    dependencies = [];

  };

  CheckAttach = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CheckAttach-2015-06-22";
    src = fetchgit {
      url = "git://github.com/chrisbra/CheckAttach";
      rev = "a1d86be7e69b25b41ce1a7fe2d2844330f783b68";
      sha256 = "0scshz5vc5j2lhjj5is4y392xarwsdh4z3y7kyibq3d7fmszksgn";
    };
    dependencies = [];

  };

  Gist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Gist-2015-10-25";
    src = fetchgit {
      url = "git://github.com/mattn/gist-vim";
      rev = "88c331e2e07765090112a396e5e119b39b5aa754";
      sha256 = "0z7qnkgv8ryyiwikz6v6vpqypr2gh2hih27cil02rs4ci4041w74";
    };
    dependencies = [];

  };

  Hoogle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Hoogle-2015-12-24";
    src = fetchgit {
      url = "git://github.com/Twinside/vim-hoogle";
      rev = "a5db36f048ac16ab9774fc86f36cd4ae9a444932";
      sha256 = "1855n6dsimbc0brfbmmkx1gszhmgfghm1h1mpi95mq9qzbwkgjri";
    };
    dependencies = [];

  };

  Solarized = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Solarized-2011-05-09";
    src = fetchgit {
      url = "git://github.com/altercation/vim-colors-solarized";
      rev = "528a59f26d12278698bb946f8fb82a63711eec21";
      sha256 = "05d3lmd1shyagvr3jygqghxd3k8a4vp32723fvxdm57fdrlyzcm1";
    };
    dependencies = [];

  };

  Supertab = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Supertab-2016-01-03";
    src = fetchgit {
      url = "git://github.com/ervandew/supertab";
      rev = "66511772a430a5eaad7f7d03dbb02e8f33c4a641";
      sha256 = "1kxxgplsc40wyl7yj3dpcjjgysd41cd32ppcpnj5knphpjw7abp4";
    };
    dependencies = [];

  };

  Syntastic = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Syntastic-2016-06-12";
    src = fetchgit {
      url = "git://github.com/scrooloose/syntastic";
      rev = "d6b96c079be137c83009827b543a83aa113cc011";
      sha256 = "1hb1vs0sqzpjbh4l2q1rfhh4mxvhn08pin3glba26p37639w9qqc";
    };
    dependencies = [];

  };

  Tabular = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tabular-2016-05-04";
    src = fetchgit {
      url = "git://github.com/godlygeek/tabular";
      rev = "00e1e7fcdbc6d753e0bc8043e0d2546fa81bf367";
      sha256 = "185jpisk9hamcwb6aiavdzjdbbigzdra8f4mgs98r9cm9j448xkz";
    };
    dependencies = [];

  };

  Tagbar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tagbar-2015-06-19";
    src = fetchgit {
      url = "git://github.com/majutsushi/tagbar";
      rev = "7b36c46d17d57db34fdb0adac9ba6382d0bb5e66";
      sha256 = "10n1c55r2arj89man01hq9dlp2lwya9gma2jh8lhhy8p9zfl95w6";
    };
    dependencies = [];

  };

  The_NERD_Commenter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_Commenter-2016-06-10";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdcommenter";
      rev = "e2d47bec2662d5fcd324d17e22dc37f38c97bf2d";
      sha256 = "099i7jksdp4c4m7imv96xji4lbjscdns37fsr2qgn7zw5pjgjbw4";
    };
    dependencies = [];

  };

  The_NERD_tree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_tree-2016-06-10";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdtree";
      rev = "d280b15ba9388ab93f3401b26877a13fdb8ed816";
      sha256 = "19mlvmlg1lccr2kkigbggv3jfl0bdc5r6lpa2jds1j20gxp9zhwi";
    };
    dependencies = [];

  };

  UltiSnips = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "UltiSnips-2016-05-16";
    src = fetchgit {
      url = "git://github.com/SirVer/ultisnips";
      rev = "1c6b4f75a006c4411d01a1234cabda3eb4aded1a";
      sha256 = "0m9sfq9d9qvrx5valg0xz9bi0y2zi3790rg1qlnin4h1gbj5axjb";
    };
    dependencies = [];

  };

  VimOutliner = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "VimOutliner-2015-10-01";
    src = fetchgit {
      url = "git://github.com/vimoutliner/vimoutliner";
      rev = "cb41cfd6d636e1243e7e9c46b35fc5cb50588069";
      sha256 = "16szrm282l608i1v3z1vfnqrnk5x4gfljvvxqaszzm4qgdg90qg7";
    };
    dependencies = [];

  };

  WebAPI = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "WebAPI-2016-05-12";
    src = fetchgit {
      url = "git://github.com/mattn/webapi-vim";
      rev = "ca89bd5867e76b154d4eca325b5a9ad6509fccc5";
      sha256 = "138rplbmvxicxjkkbvskck3b91rill53y22yrnnd9rj7zh9hj0zm";
    };
    dependencies = [];

  };

  YankRing = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YankRing";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=23487";
      name = "yankring_190.zip";
      sha256 = "0nnxpsfjp2p9jvs3y5ynnd5s56snz9927zdp9bgmay2jgxfmp0si";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=1234";
    };

    sourceRoot = ".";
  };

  commentary = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "commentary-2016-03-10";
    src = fetchgit {
      url = "git://github.com/tpope/vim-commentary";
      rev = "73e0d9a9d1f51b6cc9dc965f62669194ae851cb1";
      sha256 = "1z409hpdk22v2ccx2y3sgcjf4fmnq7pyjfnk72srpqydfivxsl13";
    };
    dependencies = [];

  };

  ctrlp-py-matcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-py-matcher-2016-01-13";
    src = fetchgit {
      url = "git://github.com/FelikZ/ctrlp-py-matcher";
      rev = "8a803267a741cff3d6147650745f83c8f2125578";
      sha256 = "0d5a7cqjh58l8qgj92s06f2ia83w51g4cic61qxd6sykv9xqiz17";
    };
    dependencies = [];

  };

  ctrlp-z = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-z-2015-10-17";
    src = fetchgit {
      url = "git://github.com/amiorin/ctrlp-z";
      rev = "d1a69ec623ce24b9a30fc8fe3cd468c322b03026";
      sha256 = "16nsj1g8lqmyizlb5ijwhf4dsmh0xv1kwqq6jxvhaf55vfga82yl";
    };
    dependencies = [];

  };

  extradite = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "extradite-2015-09-22";
    src = fetchgit {
      url = "git://github.com/int3/vim-extradite";
      rev = "52326f6d333cdbb9e9c6d6772af87f4f39c00526";
      sha256 = "0c89i0spvdm9vi65q15qcmsfmwa9rds2wmaq1kf6s7q7ywvs6w8i";
    };
    dependencies = [];

  };

  fugitive = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fugitive-2016-05-11";
    src = fetchgit {
      url = "git://github.com/tpope/vim-fugitive";
      rev = "3439f999b138254e4bb56187fc91f91f545b4b12";
      sha256 = "0b617wljhcbz6w789j72lp4riplcb6m3b2h8x84awp2rls6k130b";
    };
    dependencies = [];

  };

  ghcmod = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ghcmod-2016-01-25";
    src = fetchgit {
      url = "git://github.com/eagletmt/ghcmod-vim";
      rev = "815616e8b7d64677d6092e95bc6a3e83d2e035d4";
      sha256 = "00pl4zimbhcfpjg326qkjxr4s4d21kzl4j617382rvqbingrm8is";
    };
    dependencies = [];

  };

  vim-autoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-autoformat-2016-06-10";
    src = fetchgit {
      url = "git://github.com/Chiel92/vim-autoformat";
      rev = "9742ae2dfb46b26b9aed39491afe3d3ecb5eafd0";
      sha256 = "0lagj6977vbjvzk01sf43hhmj1jh7d2sa478igjmkw8j3gwvxcmq";
    };
    dependencies = [];

  };

  vim-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nix-2016-05-31";
    src = fetchgit {
      url = "git://github.com/LnL7/vim-nix";
      rev = "9ac8876e5beb824018b9a09d4640f7efc2fbc8ae";
      sha256 = "0whdf56c63vp4c3b2jfl1x5c0dxxrzwvxkfm5951qzpfy6xwg27x";
    };
    dependencies = [];

  };

  deoplete-nvim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-nvim-2016-06-11";
    src = fetchgit {
      url = "git://github.com/Shougo/deoplete.nvim";
      rev = "eac8020ef6f740df9109fa557b46a488f98103f1";
      sha256 = "0fsg9mr23qsqhvzjmj626nd873zqwyxzvr5b1i97l0g6zwq3q8i8";
    };
    dependencies = [];

  };

  deoplete-jedi = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-jedi-2016-06-5";
    src = fetchgit {
      url = "git://github.com/zchee/deoplete-jedi";
      rev = "36aec0d7166f9e18e05b45468e161f01909d77ec";
      sha256 = "0h8vn7r5fkwvbxhqx6xh95iq1klz9ppbax9l3rxlfkp3w67kkj2k";
    };
    dependencies = [];

  };

  Spacegray-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Spacegray-vim-2016-06-04";
    src = fetchgit {
      url = "git://github.com/ajh17/Spacegray.vim";
      rev = "adb621e3d1df5f55d60383717bbae4533fda9c62";
      sha256 = "15n92rllri11ckdy1dykllx7xpgscvhfqa55z5sl66zicnrv89c9";
    };
    dependencies = [];

  };

  vim-closetag = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-closetag-2016-04-21";
    src = fetchgit {
      url = "git://github.com/alvan/vim-closetag";
      rev = "26e41a5b0c3752d5300506a49120d9dff19d8323";
      sha256 = "0c8x25hb912jmhf5jpfll08937wr2yls28i9divldm9jkmxvcx2k";
    };
    dependencies = [];

  };

  vim-css-color = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-css-color-2016-06-12";
    src = fetchgit {
      url = "git://github.com/ap/vim-css-color";
      rev = "ba98bd138ee15dbf6b6dc3b7080c0e65e0657c76";
      sha256 = "0l76yqd3cvdm41dx720skbphwqsza51xaf7vi8jlknsqnrb6z1kf";
    };
    dependencies = [];

  };

  neomake = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neomake-2016-06-08";
    src = fetchgit {
      url = "git://github.com/benekastah/neomake";
      rev = "0de96a8a906d254ee3b5e6cd1e9838f1c1cc59c5";
      sha256 = "1adq47ra0vf5kak7m65gyaxi1jkbdi7647bb73785j3sx5q41v0f";
    };
    dependencies = [];

  };

  vim-hdevtools = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hdevtools-2012-12-29";
    src = fetchgit {
      url = "git://github.com/bitc/vim-hdevtools";
      rev = "474947c52ff9c93dd36f3c49de90bd9a78f0baa1";
      sha256 = "1wwjb9m2l9q75d408jzq9bwv5i376bfgs6vc3ihwwlawcrmhjpxz";
    };
    dependencies = [];

  };

  vim-tmux-navigator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-tmux-navigator-2016-06-03";
    src = fetchgit {
      url = "git://github.com/christoomey/vim-tmux-navigator";
      rev = "57701ac650990010ea97b1b4d64779d0b60c769b";
      sha256 = "0kl9as63h8bfkmqhq9myma6z7xvp30hiqcnxham4cvd6vhph3b7j";
    };
    dependencies = [];

  };

  spacevim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "spacevim-2016-06-08";
    src = fetchgit {
      url = "git://github.com/ctjhoa/spacevim";
      rev = "c8811a397249508432199786abbbd41429b6c90b";
      sha256 = "0a41pjc6qd378y8sg2sp65k0s32ssn9pkk6yyss92k97rlx2bsjp";
    };
    dependencies = [];

  };

  ctrlp-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-vim-2016-06-08";
    src = fetchgit {
      url = "git://github.com/ctrlpvim/ctrlp.vim";
      rev = "cd99e43613202d56b2adfc8f9bd216734a9601fd";
      sha256 = "0inlwdl27rsjq9jaa37w21kgbvf6v8351xzqz6y2f6s5ciwbhfm3";
    };
    dependencies = [];

  };

  vim-jade = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jade-2016-02-11";
    src = fetchgit {
      url = "git://github.com/digitaltoad/vim-jade";
      rev = "0a7ec2edaa3f7fbe353f8fd5bf06d3c043d70c81";
      sha256 = "0qlwbywnx6sl2xacdialpmg1d2wmjkdsdklz97k8086glkairs10";
    };
    dependencies = [];

  };

  neco-ghc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-ghc-2016-05-07";
    src = fetchgit {
      url = "git://github.com/eagletmt/neco-ghc";
      rev = "b91b30f145d4daaf7e50d083e377bd9fbfdc670b";
      sha256 = "1fnxqqp4p7kxzs7svia33wikrzyav41qlncjpmbz6ss8jb9bk18b";
    };
    dependencies = [];

  };

  vim-localvimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-localvimrc-2016-06-06";
    src = fetchgit {
      url = "git://github.com/embear/vim-localvimrc";
      rev = "f104384cd9127b5a75ed889b551fd7f46faeb74a";
      sha256 = "0k1ava8nhshkm7llhmagpsmvgwy8xcc0mn3chdk6hz8gzz9755py";
    };
    dependencies = [];

  };

  vim-haskellConcealPlus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellConcealPlus-2016-05-13";
    src = fetchgit {
      url = "git://github.com/enomsg/vim-haskellConcealPlus";
      rev = "81dfb51ff8e471fb1f30659a10daaf1bdd65fb03";
      sha256 = "0vm76gxw62lkyxccrlnn8sblfl3d51svwfra9wfixq4h51jdggyr";
    };
    dependencies = [];

  };

  YUNOcommit-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YUNOcommit-vim-2014-11-26";
    src = fetchgit {
      url = "git://github.com/esneider/YUNOcommit.vim";
      rev = "981082055a73ef076d7e27477874d2303153a448";
      sha256 = "0mjc7fn405vcx1n7vadl98p5wgm6jxrlbdbkqgjq8f1m1ir81zab";
    };
    dependencies = [];

  };

  vim-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-go-2016-06-11";
    src = fetchgit {
      url = "git://github.com/fatih/vim-go";
      rev = "6efcfb275c8f7779bfc0738da730dfab19f157fe";
      sha256 = "14n7phv3b4s7fhz94ziafakd0wl6n4z3a12i5qq2hdavi98kd640";
    };
    dependencies = [];

  };

  vim-colorschemes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorschemes-2016-03-18";
    src = fetchgit {
      url = "git://github.com/flazz/vim-colorschemes";
      rev = "189f5182bb70fd35d0f56fee451c3f22a2a80135";
      sha256 = "1j3r99av9rzdrp8w0c86n0r4kgiv8xry5xdghc1871kvz77sq5d4";
    };
    dependencies = [];

  };

  psc-ide-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "psc-ide-vim-2016-04-26";
    src = fetchgit {
      url = "git://github.com/frigoeu/psc-ide-vim";
      rev = "27c000f0f27c7a4d05f001320ddcf1ae15b22eb7";
      sha256 = "1vgxf5kziv00mi346zw3b2dnxygxk0jyxg41y6w1j22yrp9id1k2";
    };
    dependencies = [];

  };

  vim-jsonnet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsonnet-2016-05-10";
    src = fetchgit {
      url = "git://github.com/google/vim-jsonnet";
      rev = "9cde81ff3f1afb64f8e6b51e8ebba25b074e26f8";
      sha256 = "156lbh1xgw3vrgbdfax3mhyfdm2r6r0ak42bs001ykpqmn6dxbrx";
    };
    dependencies = [];

  };

  vim-leader-guide = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-leader-guide-2016-05-17";
    src = fetchgit {
      url = "git://github.com/hecal3/vim-leader-guide";
      rev = "333bd74c6f6ad18d653061f469342f9a37664256";
      sha256 = "07y4rq9d45vak5gm0hm1aazsh8r0k631aa9d0q9v9iz9k3v7irgw";
    };
    dependencies = [];

  };

  idris-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "idris-vim-2016-01-29";
    src = fetchgit {
      url = "git://github.com/idris-hackers/idris-vim";
      rev = "e1711749f5078f5a9fa53cd15a37627ea9d239f2";
      sha256 = "0mbywk1mwbx3hjzrv7ypp5m800xjj08hxlfmd0piljg41xwkgk5q";
    };
    dependencies = [];

  };

  calendar-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "calendar-vim-2016-05-19";
    src = fetchgit {
      url = "git://github.com/itchyny/calendar.vim";
      rev = "f49bd337a4643bb58df0fa4df230d60bdfeef022";
      sha256 = "06hzvcpkgz51jl6zj67ycga5p9n1y6kk335d3cha24divp4ll1jb";
    };
    dependencies = [];

  };

  lightline-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lightline-vim-2016-06-12";
    src = fetchgit {
      url = "git://github.com/itchyny/lightline.vim";
      rev = "430ce2cb063b39a0c7950cafd617e333acb6759a";
      sha256 = "0336c17vkfh60cvj86y35lqz1xcd80csrlb985k1hyd5s7cayp42";
    };
    dependencies = [];

  };

  thumbnail-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "thumbnail-vim-2016-03-17";
    src = fetchgit {
      url = "git://github.com/itchyny/thumbnail.vim";
      rev = "4afdc473b47d162610965fa5ed15fa855cca65d4";
      sha256 = "1z5a9dqb788ll5j8gg3hdjjggwpx0b073v5dr8zlrk1zjwah56gw";
    };
    dependencies = [];

  };

  vim-ipython = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ipython-2015-06-23";
    src = fetchgit {
      url = "git://github.com/ivanov/vim-ipython";
      rev = "42499f094b805b90b683afa5009cee99abd0bb75";
      sha256 = "10wpfvfs8yv1bvzra4d5zy5glp62gbalpayxx7mkalhr2ccppy3x";
    };
    dependencies = [];

  };

  vim-hier = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hier-2011-08-27";
    src = fetchgit {
      url = "git://github.com/jceb/vim-hier";
      rev = "0b8c365263551a67404ebd7e528c55e17c1d3de7";
      sha256 = "118pd9sx1bl9vfr89xrf536hfx4l162a43a1qpwpkqxzb9a3ca7n";
    };
    dependencies = [];
    buildInputs = [ vim ];
  };

  vim-orgmode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-orgmode-2016-05-15";
    src = fetchgit {
      url = "git://github.com/jceb/vim-orgmode";
      rev = "e0d56a6e93798b7a503bb4ab86fec016cd74d466";
      sha256 = "0704wli8n1x4v40mdfj0icjarr52iqvw2byzsvyzb420wpf1nqpb";
    };
    dependencies = [];

  };

  vim-buffergator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-buffergator-2016-04-07";
    src = fetchgit {
      url = "git://github.com/jeetsukumaran/vim-buffergator";
      rev = "611966d1ced784d5659c5dc07e984fabd95d917f";
      sha256 = "1brb6qwlgxq4zcmrqp7wf2zvfvdq4zm8ynzg8wg9rq5cmyp8f61z";
    };
    dependencies = [];

  };

  tslime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tslime-vim-2016-06-14";
    src = fetchgit {
      url = "git://github.com/jgdavey/tslime.vim";
      rev = "c980c76bbfc9a523fcf1edf08580d0d3a486e8f2";
      sha256 = "0gifyxwlspfnkni886adwn9kc0dckanjk0097y8pwxh7qbwfydf1";
    };
    dependencies = [];

  };

  vim-nerdtree-tabs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nerdtree-tabs-2014-09-25";
    src = fetchgit {
      url = "git://github.com/jistr/vim-nerdtree-tabs";
      rev = "0decec122e9bb3e9328b01fa20a9650e79cc6ca7";
      sha256 = "0m51vpxq0d3mxy9i18hczsbqsqi7vlzwgjnpryb8gb5wmy999d6l";
    };
    dependencies = [];

  };

  zenburn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zenburn-2015-09-18";
    src = fetchgit {
      url = "git://github.com/jnurmine/zenburn";
      rev = "f7847fb1531b91e2b4bb4aed5db3146f07765179";
      sha256 = "1las12jznf25dkxrjk3s9l70c6wnpjisngmvi83bhw5gvx4c7mq5";
    };
    dependencies = [];

  };

  vim-colorstepper = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorstepper-2016-01-28";
    src = fetchgit {
      url = "git://github.com/jonbri/vim-colorstepper";
      rev = "f23ba0d995d41508a2dc9471cf31d3d01a4b5f05";
      sha256 = "05ykxn0gmh8liz0zv5hb8df1ajggxp88izq3825m0yb3ma3k1jqs";
    };
    dependencies = [];

  };

  vim-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xdebug-2012-08-15";
    src = fetchgit {
      url = "git://github.com/joonty/vim-xdebug";
      rev = "a4980fa65f7f159780593ee37c178281691ba2c4";
      sha256 = "1qh18r0sm4gh95sjbi2hnflvxdl4gk00jyy3n7z4i1gnx9ihxjqw";
    };
    dependencies = [];
    postInstall = false;
  };

  fzf-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fzf-vim-2016-06-14";
    src = fetchgit {
      url = "git://github.com/junegunn/fzf.vim";
      rev = "0867178d9963e9f971c7799b0820aab985676c3c";
      sha256 = "09d9v4anraxp6bk54mkx4w7j256b21m7ik77l647j3bnyn0z3wf8";
    };
    dependencies = [];

  };

  limelight-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "limelight-vim-2016-05-17";
    src = fetchgit {
      url = "git://github.com/junegunn/limelight.vim";
      rev = "e93c8013bb66d4b6622e24e0e3a97e71a032d9ec";
      sha256 = "1xq3fa44fz3dfl52y0ygm21pa8b121b5lsdflcvn0igvisdkzl6g";
    };
    dependencies = [];

  };

  vim-peekaboo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-peekaboo-2016-05-31";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-peekaboo";
      rev = "35ee385d451d06c93177d6bb268dcefd19b091da";
      sha256 = "1ix03w0rcn5l8ljszhsn53gsqmpsk12qv1s6imd5nhdf66njhlks";
    };
    dependencies = [];

  };

  vim-eighties = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eighties-2015-11-02";
    src = fetchgit {
      url = "git://github.com/justincampbell/vim-eighties";
      rev = "62a9719df45fddd0456bf47420fc4768f9c8f5a5";
      sha256 = "1ada7f2lhdwjqmy5kxma69s215z4phi4khh8hsy5qd6k3a4bvyrs";
    };
    dependencies = [];

  };

  latex-box = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "latex-box-2015-06-01";
    src = fetchgit {
      url = "git://github.com/latex-box-team/latex-box";
      rev = "3c2901e12cb78bfb2be58ba4c62a488612550fe1";
      sha256 = "1z4mdy47cpwcdhvy8mr72vhlybxn1y59yd3ixf6ids1bzpkrd7zl";
    };
    dependencies = [];

  };

  vim-jinja = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jinja-2016-05-20";
    src = fetchgit {
      url = "git://github.com/lepture/vim-jinja";
      rev = "0bcc2993ef13bacd4bf1a0d91eb17652f7aedb86";
      sha256 = "1wypg9rf7q65g6l3ajp75gdb4cd7spckzd4b7ccg8c47vd937dcj";
    };
    dependencies = [];

  };

  vimtex = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimtex-2016-06-14";
    src = fetchgit {
      url = "git://github.com/lervag/vimtex";
      rev = "1211d5725331a221329f8cd98756c8ef68556fd9";
      sha256 = "0hjajg8ls2gl0jjrcb7m5qrvvzlm86jac8786fi56iql3r1yvlil";
    };
    dependencies = [];

  };

  vim-easymotion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easymotion-2016-05-07";
    src = fetchgit {
      url = "git://github.com/lokaltog/vim-easymotion";
      rev = "5c6f3cd9a713491e6b32752a05c45198aa91540a";
      sha256 = "0nr50c6hsg43bc86gkiram5whkggjpszffl8xkqxdmlspz9h96v3";
    };
    dependencies = [];

  };

  vim-xkbswitch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xkbswitch-2016-01-31";
    src = fetchgit {
      url = "git://github.com/lyokha/vim-xkbswitch";
      rev = "89fa3fc16251f2e97281d29ade3ee022ba285003";
      sha256 = "16wahaz9d6jyqlvmsn764xqircrwaap3pn4fbgmly7vfmdvq4p8b";
    };
    dependencies = [];
    patchPhase = ''
      substituteInPlace plugin/xkbswitch.vim \
              --replace /usr/local/lib/libxkbswitch.so ${xkb_switch}/lib/libxkbswitch.so
    '';
    buildInputs = [ xkb_switch ];
  };

  vim-startify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-startify-2016-06-08";
    src = fetchgit {
      url = "git://github.com/mhinz/vim-startify";
      rev = "dbaa0254249a5d9685ffc9513557bb811fad65b4";
      sha256 = "1l65ah2k437rhp3rr81fgrwwr7vvipfrj5vlixx49zxgzy489wr4";
    };
    dependencies = [];

  };

  lushtags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lushtags-2016-04-26";
    src = fetchgit {
      url = "git://github.com/mkasa/lushtags";
      rev = "641e4163d078e7c3844f2ac82a8153a3ef06484b";
      sha256 = "1zqgvflkw0pnrv6bzvlsd98sc2m7nk5w3bzqdzj3xdi8ahqx239g";
    };
    dependencies = [];

  };

  hlint-refactor-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hlint-refactor-vim-2015-12-05";
    src = fetchgit {
      url = "git://github.com/mpickering/hlint-refactor-vim";
      rev = "fffb044ecef854a82c5c2efda252e09044ba03e0";
      sha256 = "0z8d31arfy9aidg1dwj5msnnx799d9r7njkgh51z695w6ayxn6p8";
    };
    dependencies = [];

  };

  vim-stylish-haskell = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-stylish-haskell-2015-05-10";
    src = fetchgit {
      url = "git://github.com/nbouscal/vim-stylish-haskell";
      rev = "c664376ba814de3f87cb7641f90b2c6a9dd53671";
      sha256 = "1xm5ark2mwphznv3xsyzgcldnr52i5jzk1pfqdh0080j07aama8j";
    };
    dependencies = [];

  };

  haskell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "haskell-vim-2016-05-17";
    src = fetchgit {
      url = "git://github.com/neovimhaskell/haskell-vim";
      rev = "f73cdcdf72e9200420fc74491b6cd215512c3330";
      sha256 = "1fgcfcslb6p84xcv1ighd8i4p4960vac7f7zpvl0d7bpp75ci07b";
    };
    dependencies = [];

  };

  shabadou-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "shabadou-vim-2014-07-27";
    src = fetchgit {
      url = "git://github.com/osyo-manga/shabadou.vim";
      rev = "c5af30bb0c028d53cfd89e00cab636c844034a9a";
      sha256 = "1rjdbjsyhs514cqysrr4cr3qva6v1nixjwdmg3j1jlkjbs5glbir";
    };
    dependencies = [];

  };

  vim-watchdogs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-watchdogs-2016-05-29";
    src = fetchgit {
      url = "git://github.com/osyo-manga/vim-watchdogs";
      rev = "a1136db1d8806a03fc8ea81aa60e82d4cba57fb5";
      sha256 = "1qk0wg11x6xwakqqbnx47ma5arsam55jqag0hxsf6is2yjqxb825";
    };
    dependencies = [];

  };

  vim-racer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-racer-2016-05-31";
    src = fetchgit {
      url = "git://github.com/racer-rust/vim-racer";
      rev = "392e5818039a13f0cc3f819afcbb31291b1635a4";
      sha256 = "0fs3zlsc1h4a58m0xlv11g5vzfvhjrinnmxh7xmgjnnd4njx8iax";
    };
    dependencies = [];

  };

  purescript-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "purescript-vim-2016-01-04";
    src = fetchgit {
      url = "git://github.com/raichoo/purescript-vim";
      rev = "92dd6bc647b45444e9d5e0550bdc3c56928f9762";
      sha256 = "090vpff58lzzhqp28p27am5s8s6ngjxw6j4y46zaixcxxx7wqzha";
    };
    dependencies = [];

  };

  rust-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rust-vim-2016-06-05";
    src = fetchgit {
      url = "git://github.com/rust-lang/rust.vim";
      rev = "e064f270e85e0cbb7bd643aeda3e7088378341f7";
      sha256 = "04s3c1hwxcprvzn8wx39f9mg3rmgwvqvinqwbfm591pjpialvmpk";
    };
    dependencies = [];

  };

  neocomplete-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neocomplete-vim-2016-06-07";
    src = fetchgit {
      url = "git://github.com/shougo/neocomplete.vim";
      rev = "14698b37d10b8ae18a4850aa784fdd3130e4ba3e";
      sha256 = "08bg6yafp68gh82afzzn9msb7adydihdvxyzigvjzr94bzv4n4ab";
    };
    dependencies = [];

  };

  neosnippet-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-snippets-2016-05-26";
    src = fetchgit {
      url = "git://github.com/shougo/neosnippet-snippets";
      rev = "dbce664a473e2344d2cc4e494fb5e408452646e2";
      sha256 = "008brypf2jc9kl1gqyl1x2b1qx0bzvvfc0qqg0aniva2hwsda38k";
    };
    dependencies = [];

  };

  neosnippet-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-vim-2016-06-11";
    src = fetchgit {
      url = "git://github.com/shougo/neosnippet.vim";
      rev = "23eac4b080bb9788fbe61a0b93c7cf39e533f490";
      sha256 = "01hbglhvgkfq78hxyh32afi4q47y6l3lm7yn4cz532cqd7ac78ij";
    };
    dependencies = [];

  };

  unite-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "unite-vim-2016-06-11";
    src = fetchgit {
      url = "git://github.com/shougo/unite.vim";
      rev = "27a97d3eacd209c4f6e15c98e9217a4f6c438ac5";
      sha256 = "14d87skqrsdb61nqpdch584hi0hpb5a0nqf35q5727pz6ckch32f";
    };
    dependencies = [];

  };

  vimproc-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimproc-vim-2016-06-11";
    src = fetchgit {
      url = "git://github.com/shougo/vimproc.vim";
      rev = "c2f6b82af60a4e7acde0e8dc4e6b6f5dc1cc8e1d";
      sha256 = "1h79c0fskvalasji290qz89y1s9c1mic7h1p82p1im036jvmkf22";
    };
    dependencies = [];
    buildInputs = [ which ];

    buildPhase = ''
      substituteInPlace autoload/vimproc.vim \
        --replace vimproc_mac.so vimproc_unix.so \
        --replace vimproc_linux64.so vimproc_unix.so \
        --replace vimproc_linux32.so vimproc_unix.so
      make -f make_unix.mak
    '';
  };

  vimshell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimshell-vim-2016-06-11";
    src = fetchgit {
      url = "git://github.com/shougo/vimshell.vim";
      rev = "d36fde6da558d4cad7a1d03a07fd5e1fcf299141";
      sha256 = "0xx84552k7ziymp81slgxsym1nvzkyyyf1d31y7k8cqbvq87nbn1";
    };
    dependencies = [ "vimproc-vim" ];
  };

  gundo-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gundo-vim-2016-01-19";
    src = fetchgit {
      url = "git://github.com/sjl/gundo.vim";
      rev = "e7fe41024ace9047eee610f23311d44fd9d917c0";
      sha256 = "14mx617mxh7q6rhjfcnv080hpr965vhqzfwhlizpmzc16lsf7ni1";
    };
    dependencies = [];

  };

  vim-hardtime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hardtime-2016-05-03";
    src = fetchgit {
      url = "git://github.com/takac/vim-hardtime";
      rev = "acf59c8df88e1445c145dfca626957d54a1310c3";
      sha256 = "1q7lhj6ll3lycsxqj0ymm7pb6m1sdglgip7wkirjv357yxl7y7kr";
    };
    dependencies = [];

  };

  vim-expand-region = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-expand-region-2013-08-19";
    src = fetchgit {
      url = "git://github.com/terryma/vim-expand-region";
      rev = "966513543de0ddc2d673b5528a056269e7917276";
      sha256 = "0l30wjlk4vxr16f1njnvf8aw9yg9p9jisvcxbcg3znsq5q8ix6zv";
    };
    dependencies = [];

  };

  vimpreviewpandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimpreviewpandoc-2016-03-07";
    src = fetchgit {
      url = "git://github.com/tex/vimpreviewpandoc";
      rev = "b109d41ad6478df5ec7f1311950c6efca66f36e4";
      sha256 = "1gx326xarjs3qjygpkrknncad90crjqfx8v6pir4r7k1hl7dfxc4";
    };
    dependencies = [];

  };

  vim-quickrun = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-quickrun-2016-06-09";
    src = fetchgit {
      url = "git://github.com/thinca/vim-quickrun";
      rev = "bb4daff0342ce3311b7f6c2fd3e2160f2be9e374";
      sha256 = "11baxdcqr8854ijp0gkwwjl9navv8x1dv53p2isiq5vpqiq4n3mw";
    };
    dependencies = [];

  };

  molokai = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "molokai-2015-11-11";
    src = fetchgit {
      url = "git://github.com/tomasr/molokai";
      rev = "c67bdfcdb31415aa0ade7f8c003261700a885476";
      sha256 = "1piszjr5kyw43ac1f0jh9z88g824xknshrkchbys9qxlz7pd831s";
    };
    dependencies = [];

  };

  vim-eunuch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eunuch-2016-04-16";
    src = fetchgit {
      url = "git://github.com/tpope/vim-eunuch";
      rev = "5ee2b82b565e6c6d80f1cb7735c78f66a159b198";
      sha256 = "108v98qy49w2pgzndmqc9nydmsql2bnbcc849wshvkxgca349ixc";
    };
    dependencies = [];

  };

  hasksyn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hasksyn-2014-09-03";
    src = fetchgit {
      url = "git://github.com/travitch/hasksyn";
      rev = "c434040bf13a17ca20a551223021b3ace7e453b9";
      sha256 = "09998lnfcshqis5m062wlag6y476imq9jday9gp4ayjjl1cp3cwx";
    };
    dependencies = [];

  };

  vim-haskellconceal = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellconceal-2014-10-28";
    src = fetchgit {
      url = "git://github.com/twinside/vim-haskellconceal";
      rev = "f73c5dd660b7009a050b131783d7c17b4954e4d9";
      sha256 = "1a1v0m3qj0gian3mp5xynf2ghscr3xaid37b0wi38bb4f2qrigqy";
    };
    dependencies = [];

  };

  youcompleteme = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "youcompleteme-2016-06-13";
    src = fetchgit {
      url = "git://github.com/valloric/youcompleteme";
      rev = "871387bd2a2ed9270ccc17ed63dde99c840deab5";
      sha256 = "19ll1nh6nxl31zdajz9kdgw18mvsy4d630435z604rxik2rgbh3d";
    };
    dependencies = [];
    buildInputs = [
      python go cmake
      (if stdenv.isDarwin then llvmPackages.clang else llvmPackages.clang-unwrapped)
      llvmPackages.llvm
    ] ++ stdenv.lib.optional stdenv.isDarwin Cocoa;

    propogatedBuildInputs = [
      rustracerd
    ];

    buildPhase = ''
      patchShebangs .
      substituteInPlace plugin/youcompleteme.vim \
        --replace "'ycm_path_to_python_interpreter', '''" "'ycm_path_to_python_interpreter', '${python}/bin/python'"

      mkdir build
      pushd build
      cmake -G "Unix Makefiles" . ../third_party/ycmd/cpp -DPYTHON_LIBRARIES:PATH=${python}/lib/libpython2.7.so -DPYTHON_INCLUDE_DIR:PATH=${python}/include/python2.7 -DUSE_CLANG_COMPLETER=ON -DUSE_SYSTEM_LIBCLANG=ON
      make ycm_core -j''${NIX_BUILD_CORES} -l''${NIX_BUILD_CORES}}
      ${python}/bin/python ../third_party/ycmd/build.py --gocode-completer --clang-completer --system-libclang
      popd
    '';

    meta = {
      description = "Fastest non utf-8 aware word and C completion engine for Vim";
      homepage = http://github.com/Valloric/YouCompleteMe;
      license = stdenv.lib.licenses.gpl3;
      maintainers = with stdenv.lib.maintainers; [marcweber jagajaga];
      platforms = stdenv.lib.platforms.unix;
    };
  };

  vim-airline-themes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-themes-2016-06-06";
    src = fetchgit {
      url = "git://github.com/vim-airline/vim-airline-themes";
      rev = "796478723c01a275269b96f63ee5cd5b44a342f4";
      sha256 = "1irvzv1sq12y2q6yjb26b89j5pxs5cia35dax093q6h88ywq709g";
    };
    dependencies = [];

  };

  vim-pandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-2016-05-24";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc";
      rev = "cca2326046fd9bf44276e6d44f106c90d80eca25";
      sha256 = "106dxdll11sj5vi34a0nq5kmfbp13g80ix26m6k9snxjx2y79y3s";
    };
    dependencies = [];

  };

  vim-pandoc-after = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-after-2015-06-01";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc-after";
      rev = "4377665e5c98f29ea838deb3b942200b8dd096ef";
      sha256 = "1379g174pvsaw1wdv1n18gby84sv59rsamfcgq9bqd4kg54g6h3j";
    };
    dependencies = [];

  };

  vim-pandoc-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-syntax-2016-06-14";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc-syntax";
      rev = "eaf2507e0bd51ec06bc111777376b21da7340d5d";
      sha256 = "0xxsjvzv98wnfzw0j590am8za75y7gr8r480izb3db2z437micw7";
    };
    dependencies = [];

  };

  Colour-Sampler-Pack = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Colour-Sampler-Pack-2012-11-29";
    src = fetchgit {
      url = "git://github.com/vim-scripts/Colour-Sampler-Pack";
      rev = "05cded87b2ef29aaa9e930230bb88e23abff4441";
      sha256 = "03v2r18sfgs0xbgy9p56pxfdg0lsk6m7wyr5hw63wm1nzpwiipg3";
    };
    dependencies = [];

  };

  a-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "a-vim-2010-11-06";
    src = fetchgit {
      url = "git://github.com/vim-scripts/a.vim";
      rev = "2cbe946206ec622d9d8cf2c99317f204c4d41885";
      sha256 = "0h62v9z5bh9xmaq22pqdb3z79i84a5rknqm68mjpy7nq7s3q42fa";
    };
    dependencies = [];

  };

  align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "align-2012-08-07";
    src = fetchgit {
      url = "git://github.com/vim-scripts/align";
      rev = "787662fe90cd057942bc5b682fd70c87e1a9dd77";
      sha256 = "0acacr572kfh7jvavbw61q5pkwrpi1albgancma063rpax1pddgp";
    };
    dependencies = [];

  };

  changeColorScheme-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "changeColorScheme-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/changeColorScheme.vim";
      rev = "b041d49f828629d72f2232531a230d1ec5de2405";
      sha256 = "0pybhsg9k9252d4ifdc4gsar8lkmfzbvs6xkzqq1m6f35l9wqk09";
    };
    dependencies = [];

  };

  random-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "random-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/random.vim";
      rev = "b2d85eb24a38074eab37a5acf2a295e1f2ad8989";
      sha256 = "1lzy2cq4jcrsqyxlnbnd0y6j4mabm09bi7q22lf6vinqlb84w7sp";
    };
    dependencies = [];

  };

  tabmerge = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tabmerge-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/tabmerge";
      rev = "074e5f06f26e7108a0570071a0f938a821768c06";
      sha256 = "0prkyza1n49cdaslcr57w8zv15vw78mlqbzib2xipmawzjq02idq";
    };
    dependencies = [];

  };

  wombat256-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "wombat256-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/wombat256.vim";
      rev = "8734ba45dcf5e38c4d2686b35c94f9fcb30427e2";
      sha256 = "01fdvfwdfqn5xi88lfanb4lb6jmn1ma6wq6d9jj2x7qamdbpvsrg";
    };
    dependencies = [];

  };

  vim-wakatime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-wakatime-2016-06-13";
    src = fetchgit {
      url = "git://github.com/wakatime/vim-wakatime";
      rev = "cd074dcff51f12d1658902d4fe0d9f311ac94a2d";
      sha256 = "0sq7n9w4nadc0psr74g7bmgv87bqlzsmyrr4iyalz108bdgxahav";
    };
    dependencies = [];
    buildInputs = [ python ];
  };

  command-t = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "command-t-2016-06-14";
    src = fetchgit {
      url = "git://github.com/wincent/command-t";
      rev = "354c429dad34f7d163663943c948f819588b53d3";
      sha256 = "1vkvc6ckza5b4ck52hv4rjclqi7x4f06dxkbqcqnia490m685v9q";
    };
    dependencies = [];
    buildInputs = [ perl ruby ];
    buildPhase = ''
      pushd ruby/command-t
      ruby extconf.rb
      make
      popd
    '';
  };

  goyo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "goyo-2016-04-03";
    src = fetchgit {
      url = "git://github.com/junegunn/goyo.vim";
      rev = "8e8f1d45b61e1fce7f84ee061c38f9e033e86ff9";
      sha256 = "120farhbfyzd7k1s1i68drwa5zzzm9yrcwzw45gwa2j7kqbv4hnx";
    };
    dependencies = [];

  };

  matchit-zip = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "matchit-zip";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=8196";
      name = "matchit.zip";
      sha256 = "1bbm8j1bhb70kagwdimwy9vcvlrz9ax5bk2a7wrmn4cy87f9xj4l";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=39";
    };

    unpackPhase = ''
      (
       sourceRoot=d
       mkdir $sourceRoot; cd $sourceRoot;
       unzip $src
      )
    '';
  };

  pathogen = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pathogen-2016-01-26";
    src = fetchgit {
      url = "git://github.com/tpope/vim-pathogen";
      rev = "8c91196cfd9c8fe619f35fac6f2ac81be10677f8";
      sha256 = "17d1903spczg2rk0qzg94vvq41dwhmnxwajqgzcx4lmf606cfspi";
    };
    dependencies = [];

  };

  quickfixstatus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "quickfixstatus-2011-09-02";
    src = fetchgit {
      url = "git://github.com/dannyob/quickfixstatus";
      rev = "fd3875b914fc51bbefefa8c4995588c088163053";
      sha256 = "16vxhvyxq51y7wnx0c1fmdi2yb6kfr1pxijq65gxj8qwvbak2s3v";
    };
    dependencies = [];

  };

  rainbow_parentheses = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow_parentheses-2013-03-04";
    src = fetchgit {
      url = "git://github.com/kien/rainbow_parentheses.vim";
      rev = "eb8baa5428bde10ecc1cb14eed1d6e16f5f24695";
      sha256 = "1qw84imlhq4654mxazj7j3sp5g1j3yjxi496i08iix06dm15m5s7";
    };
    dependencies = [];

  };

  sensible = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sensible-2016-03-18";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sensible";
      rev = "9e91be7e0fb42949831fe3161ef583363648aa58";
      sha256 = "1g1l3v33g9229r4g4kcx8m1yrh397yf3fn6bxis57n3lg6lmb6wm";
    };
    dependencies = [];

  };

  sleuth = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sleuth-2015-06-07";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sleuth";
      rev = "a17462708aa40a7fc0afd4effa559087d8a2c908";
      sha256 = "12s7nl3c15i9wyinhzw9biymsyw74akx96nzix9p9979nxhmi09m";
    };
    dependencies = [];

  };

  snipmate = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "snipmate-2016-06-08";
    src = fetchgit {
      url = "git://github.com/garbas/vim-snipmate";
      rev = "0c20e4136a298a73e21047d12cc5049595fb8445";
      sha256 = "1x9skkywr5shrvb9bm3mjww6kmjmck7y8g0mn9yq8psqag9j3l21";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  sourcemap = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sourcemap-2012-09-19";
    src = fetchgit {
      url = "git://github.com/chikatoike/sourcemap.vim";
      rev = "0dd82d40faea2fdb0771067f46c01deb41610ba1";
      sha256 = "1gcgnynallz420911fdfm0ccbv3zs78p69nnh2ls1r4vlfp7g350";
    };
    dependencies = [];

  };

  surround = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "surround-2016-06-01";
    src = fetchgit {
      url = "git://github.com/tpope/vim-surround";
      rev = "e49d6c2459e0f5569ff2d533b4df995dd7f98313";
      sha256 = "1v0q2f1n8ngbja3wpjvqp2jh89pb5ij731qmm18k41nhgz6hhm46";
    };
    dependencies = [];

  };

  table-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "table-mode-2016-05-08";
    src = fetchgit {
      url = "git://github.com/dhruvasagar/vim-table-mode";
      rev = "b613e39bd08ecebdb9b18100dae518050f496048";
      sha256 = "1bachhk21x507q8xp4a6a8lpsqs2miv97lnjjf6q9qh0crxhv3z8";
    };
    dependencies = [];

  };

  taglist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "taglist";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=19574";
      name = "taglist_46.zip";
      sha256 = "18cbv462vwg7vip2p99qlahm99hswav96cj4ki227kyi05q2lkjj";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=273";
    };

    setSourceRoot = ''
      export sourceRoot=taglist
      mkdir taglist
      mv doc taglist
      mv plugin taglist
    '';
  };

  tlib = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tlib-2016-04-06";
    src = fetchgit {
      url = "git://github.com/tomtom/tlib_vim";
      rev = "34b13299b5da7ad66ea387027d458bd54127687c";
      sha256 = "0dwcwqxbfq7gy3iy5smx3zqp2v62p8166vj02bhrrr5zkv8rqnb3";
    };
    dependencies = [];

  };

  undotree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "undotree-2016-05-16";
    src = fetchgit {
      url = "git://github.com/mbbill/undotree";
      rev = "97ef890fea5452c1c4c68f0d864c7969d7aba578";
      sha256 = "06mifmfqvzy8af54s0h9hjcmhxgjccikqilfz9l8hn3gdl7ixfix";
    };
    dependencies = [];

  };

  vim-addon-actions = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-actions-2014-09-22";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-actions";
      rev = "a5d20500fb8812958540cf17862bd73e7af64936";
      sha256 = "1wfkwr89sn2w97i94d0dqylcg9mr6pirjadi0a4l492nfnsh99bc";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-async = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-async-2013-10-18";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-async";
      rev = "dadc96e188f1cdacbac62129eb29a1eacfed792c";
      sha256 = "0b95l4ig8as82swhavsdica93bv5j55kvldfl7frkfp5zwcwi90f";
    };
    dependencies = ["vim-addon-signs"];

  };

  vim-addon-background-cmd = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-background-cmd-2015-12-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-background-cmd";
      rev = "abf2abf339652d2bc79da81f9d131edfe2755f5a";
      sha256 = "0csy68x686l3x5ancidxb5b6prg9k7ikybqzq3klx0gs5rmksfy4";
    };
    dependencies = ["vim-addon-mw-utils"];

  };

  vim-addon-commenting = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-commenting-2013-06-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-commenting";
      rev = "b7cf748ac1c9bf555cbd347589e3b7196030d20b";
      sha256 = "0alak8h33vada2ckb0v06y82qlib5mhyc2yswlv1rqh8ypzhq3mc";
    };
    dependencies = [];

  };

  vim-addon-completion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-completion-2015-02-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-completion";
      rev = "021c449a5ce1ce4ac0af5955e05b0279c1cc0e75";
      sha256 = "1ld059y2qwlc5bdfjm2p314s1qh31lxs54g944pw49r46s5nlslr";
    };
    dependencies = ["tlib"];

  };

  vim-addon-errorformats = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-errorformats-2014-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-errorformats";
      rev = "dcbb203ad5f56e47e75fdee35bc92e2ba69e1d28";
      sha256 = "159zqm69fxbxcv3b2y99g57bf20qrzsijcvb5rzy2njxah3049m1";
    };
    dependencies = [];

  };

  vim-addon-goto-thing-at-cursor = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-goto-thing-at-cursor-2012-01-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-goto-thing-at-cursor";
      rev = "f052e094bdb351829bf72ae3435af9042e09a6e4";
      sha256 = "1ksm2b0j80zn8sz2y227bpcx4jsv76lwgr2gpgy2drlyqhn2vlv0";
    };
    dependencies = ["tlib"];

  };

  vim-addon-local-vimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-local-vimrc-2015-03-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-local-vimrc";
      rev = "6a27f95b35befa70cd0d049329cd0920566c764b";
      sha256 = "0n8lwl1gyak149p7jpgm0qbmfj8hcg8hirx3dxdhizw0yc47ws7h";
    };
    dependencies = [];

  };

  vim-addon-manager = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-manager-2016-02-07";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-manager";
      rev = "872f9302cf0eb8e9cb6259ea4f329d2265f9e32d";
      sha256 = "14aixpj9p8b568mdh4pl7bmpw1rsc4d7axqr09g1m0a8q6rxipc7";
    };
    dependencies = [];
    buildInputs = stdenv.lib.optional stdenv.isDarwin Cocoa;
  };

  vim-addon-mru = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mru-2013-08-08";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mru";
      rev = "e41e39bd9d1bf78ccfd8d5e1bc05ae5e1026c2bb";
      sha256 = "0q6rxr9nrp63kidr3m3c2z5sda4g813pzshg0scxkjr8dxwhzdqm";
    };
    dependencies = ["vim-addon-other" "vim-addon-mw-utils"];

  };

  vim-addon-mw-utils = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mw-utils-2012-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mw-utils";
      rev = "0c5612fa31ee434ba055e21c76f456244b3b5109";
      sha256 = "147s1k4n45d3x281vj35l26sv4waxjlpqdn83z3k9n51556h1d45";
    };
    dependencies = [];

  };

  vim-addon-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-nix-2015-03-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-nix";
      rev = "2aed79ba5d8c5e6abd102de77e55e242f61b17f1";
      sha256 = "0zx1q9994py6jmm0qbbx6fc1dy5la8zfskkbvqqxssxrl5dx7vvi";
    };
    dependencies = ["vim-addon-completion" "vim-addon-goto-thing-at-cursor" "vim-addon-errorformats" "vim-addon-actions" "vim-addon-mw-utils" "tlib"];

  };

  vim-addon-other = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-other-2014-07-15";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-other";
      rev = "f78720c9cb5bf871cabb13c7cbf94378dbf0163b";
      sha256 = "0cjz7mlyfkkncas4ss7rwxb0q38ls1qw1p15hac1imscscsvyjc6";
    };
    dependencies = ["vim-addon-actions" "vim-addon-mw-utils"];

  };

  vim-addon-php-manual = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-php-manual-2015-01-01";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-php-manual";
      rev = "5f9810dd1f6e9f36a45f637ae6260ccff09256ff";
      sha256 = "1kc67f12wccqdza069b75lpcbqp4kv4r23i4mfz0ihwif5mfnhir";
    };
    dependencies = [];

  };

  vim-addon-signs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-signs-2013-04-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-signs";
      rev = "17a49f293d18174ff09d1bfff5ba86e8eee8e8ae";
      sha256 = "0i4gfp30hmw1vqjl6zxjrgkca3ikdkcnjmma2mncjmcr6f59kjzy";
    };
    dependencies = [];

  };

  vim-addon-sql = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-sql-2014-01-18";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-sql";
      rev = "05b8a0c211f1ae4c515c64e91dec555cdf20d90b";
      sha256 = "15l2201jkfml08znvkkpy7fm3wn87n91zgd9ysrf5h73amjx9y2w";
    };
    dependencies = ["vim-addon-completion" "vim-addon-background-cmd" "tlib"];

  };

  vim-addon-syntax-checker = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-syntax-checker-2013-07-12";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-syntax-checker";
      rev = "8eb7217e636ca717d4de5cd03cc0180c5b66ae77";
      sha256 = "0gcvb922w4jsi203ygbnij9xhmgc6knj9b3ivw3m0fv5ckk4iw5f";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-toggle-buffer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-toggle-buffer-2012-01-13";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-toggle-buffer";
      rev = "a1b38b9c5709cba666ed2d84ef06548f675c6b0b";
      sha256 = "1xq38kfdm36c34ln66znw841q797w5gm8bpq1x64bsf2h6n3ml03";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-xdebug-2014-08-29";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-xdebug";
      rev = "45f26407305b4ce6f8f5f37d2b5e6e4354104172";
      sha256 = "1i64ppdfp2qqq7vw1jf160mj4ikc04v39iazdab83xmiqjsh8ixw";
    };
    dependencies = ["WebAPI" "vim-addon-mw-utils" "vim-addon-signs" "vim-addon-async"];

  };

  vim-airline = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-2016-06-07";
    src = fetchgit {
      url = "git://github.com/vim-airline/vim-airline";
      rev = "7b9b68f15dc50ef3c6382bd9df3a5e70c9ddcee9";
      sha256 = "0k6imrfgp62qminwd7ilsq106dy49nwn2fsm88v546mwc9a2bccd";
    };
    dependencies = [];

  };

  vim-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-coffee-script-2015-04-20";
    src = fetchgit {
      url = "git://github.com/kchmck/vim-coffee-script";
      rev = "32fe889b8cafd3a4921ef8e6485156453ff58c42";
      sha256 = "1x2kk9jm3948avvz3ywakmhdr3x99qfa54fk1pfphny3mrfv4l65";
    };
    dependencies = [];

  };

  vim-easy-align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easy-align-2016-03-06";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-easy-align";
      rev = "0cb6b98fc155717b0a56c110551ac57d1d951ddb";
      sha256 = "10j1fz7si7xqqs4p7h66jd0xzr116cv3xjyac9p20fc0yyyg1wbh";
    };
    dependencies = [];

  };

  vim-gista = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gista-2016-04-11";
    src = fetchgit {
      url = "git://github.com/lambdalisue/vim-gista";
      rev = "7ff4d24f242d406ff71d9a65691357aee80f37f7";
      sha256 = "0hm4lnf2mxvdvc13b67cwvyp7griir5lpacnb1sgjx4dxr0w4fzz";
    };
    dependencies = [];

  };

  vim-gitgutter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gitgutter-2016-06-09";
    src = fetchgit {
      url = "git://github.com/airblade/vim-gitgutter";
      rev = "09b9144002e938844df74f48ac72c1e3118e7d39";
      sha256 = "10yyzib9znhqz298h3f67n9hz1fvm5yk6958bisimf9bg9w9rn1v";
    };
    dependencies = [];

  };

  vim-iced-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-iced-coffee-script-2013-12-27";
    src = fetchgit {
      url = "git://github.com/noc7c9/vim-iced-coffee-script";
      rev = "e42e0775fa4b1f8840c55cd36ac3d1cedbc1dea2";
      sha256 = "14yfirny359rlrr082il2ys3hxiyrbbk794rdxrs2lasjy8rb1f7";
    };
    dependencies = [];

  };

  vim-latex-live-preview = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-latex-live-preview-2016-03-16";
    src = fetchgit {
      url = "git://github.com/xuhdev/vim-latex-live-preview";
      rev = "99501642c1dd3f703ac6301ae13469f4990b7a06";
      sha256 = "0dkm3v1jqi8aq0jfpa6fdwgbfbwidc32ci1y9vhqb1prs15qrqfl";
    };
    dependencies = [];

  };

  vim-multiple-cursors = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-multiple-cursors-2016-06-03";
    src = fetchgit {
      url = "git://github.com/terryma/vim-multiple-cursors";
      rev = "51d0717f63cc231f11b4b63ee5b611f589dce1b3";
      sha256 = "1s06wp4cjdmfvljzd9gz0wawkfcpkj8l2scjdx626ml740pnhmx8";
    };
    dependencies = [];

  };

  vim-signature = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signature-2016-06-09";
    src = fetchgit {
      url = "git://github.com/kshenoy/vim-signature";
      rev = "782ed5284ddf6ef3695f8b3314facd8c6113c725";
      sha256 = "1s6n6qdn3f89h4gi8nflz84y9l59rrfn43rgn257kxsq0df0kmx2";
    };
    dependencies = [];

  };

  vim-signify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signify-2016-06-08";
    src = fetchgit {
      url = "git://github.com/mhinz/vim-signify";
      rev = "cb975a8c6fbf08385eba8d0bbc1168ae53be460a";
      sha256 = "00vi90zfkx94i0n0x4fjiz6bxfl2whxsclp8zxd4mivcqsw500jy";
    };
    dependencies = [];

  };

  vim-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-snippets-2016-06-09";
    src = fetchgit {
      url = "git://github.com/honza/vim-snippets";
      rev = "e840b91a4e86cda657519eba00766a29a614e1e2";
      sha256 = "11pns71zpg9nh3mf2g24k194371jhkkv7b3in8r9av107ijky3sb";
    };
    dependencies = [];

  };

  vim-webdevicons = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-webdevicons-2016-06-03";
    src = fetchgit {
      url = "git://github.com/ryanoasis/vim-devicons";
      rev = "0bf80d78cba8603dd4f594f1807cc5bee706db84";
      sha256 = "17r98gh4pk0xdfprjmqzp617szwq4j6yrn6pbx0l1n7k7q5crv89";
    };
    dependencies = [];

  };

  vim2hs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim2hs-2014-04-16";
    src = fetchgit {
      url = "git://github.com/dag/vim2hs";
      rev = "f2afd55704bfe0a2d66e6b270d247e9b8a7b1664";
      sha256 = "18lqrl3hqb6cmizc04bbnsh8j0g761w2q8wascbzzfw80dmxy36b";
    };
    dependencies = [];

  };

  vimwiki = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimwiki-2016-05-18";
    src = fetchgit {
      url = "git://github.com/vimwiki/vimwiki";
      rev = "4831384ab9f1c40c9e433857d958c4d9a7beb8ec";
      sha256 = "1wjbsd37h5fxkkia90h708mmqisdj0kxzm9k97jm2zq36zngmd86";
    };
    dependencies = [];

  };

  vinegar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vinegar-2016-01-30";
    src = fetchgit {
      url = "git://github.com/tpope/vim-vinegar";
      rev = "75fc3824bc09053f22735d6726c5cfd614c15642";
      sha256 = "19jl854wylmfdr9k4bfyffkz8bl4vpx1znnxzx0qj7cz2s3i9z0r";
    };
    dependencies = [];

  };

  vundle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vundle-2016-02-26";
    src = fetchgit {
      url = "git://github.com/gmarik/vundle";
      rev = "4984767509e3d05ca051e253c8a8b37de784be45";
      sha256 = "15450wz15pwv9sbvnmb60z5nshsssw4y1xy8smp332605b53kski";
    };
    dependencies = [];

  };

}
